aboutsummaryrefslogtreecommitdiffstats
path: root/tests/conftest.py
diff options
context:
space:
mode:
authorAlex Stapleton <alexs@prol.etari.at>2014-05-17 13:19:15 +0100
committerAlex Stapleton <alexs@prol.etari.at>2014-06-07 19:04:27 +0100
commite47bafb9b620b557aeb48fce4734a568d6dc0b38 (patch)
tree6fe6155fca2d6943f7615ea391e43538d6394c38 /tests/conftest.py
parentddadf40234e97cd5b7e5f7b3a3a03d38900cb291 (diff)
downloadcryptography-e47bafb9b620b557aeb48fce4734a568d6dc0b38.tar.gz
cryptography-e47bafb9b620b557aeb48fce4734a568d6dc0b38.tar.bz2
cryptography-e47bafb9b620b557aeb48fce4734a568d6dc0b38.zip
ECDSA backend
Diffstat (limited to 'tests/conftest.py')
-rw-r--r--tests/conftest.py11
1 files changed, 4 insertions, 7 deletions
diff --git a/tests/conftest.py b/tests/conftest.py
index b1326dc8..af146386 100644
--- a/tests/conftest.py
+++ b/tests/conftest.py
@@ -17,8 +17,8 @@ import pytest
from cryptography.hazmat.backends import _available_backends
from cryptography.hazmat.backends.interfaces import (
- CMACBackend, CipherBackend, DSABackend, HMACBackend, HashBackend,
- PBKDF2HMACBackend, PKCS8SerializationBackend, RSABackend,
+ CMACBackend, CipherBackend, DSABackend, EllipticCurveBackend, HMACBackend,
+ HashBackend, PBKDF2HMACBackend, PKCS8SerializationBackend, RSABackend,
TraditionalOpenSSLSerializationBackend
)
from .utils import check_backend_support, check_for_iface, select_backends
@@ -46,11 +46,8 @@ def pytest_runtest_setup(item):
TraditionalOpenSSLSerializationBackend,
item
)
- check_for_iface(
- "pkcs8_serialization",
- PKCS8SerializationBackend,
- item
- )
+ check_for_iface("pkcs8_serialization", PKCS8SerializationBackend, item)
+ check_for_iface("elliptic", EllipticCurveBackend, item)
check_backend_support(item)